==> hoc-1.34.0.tgz: package/lib/withOpenToggle.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { jsx as _jsx } from "react/jsx-runtime";
export default (function (BaseComponent) {
  var _class, _temp;

  var displayName = BaseComponent.displayName;
  return _temp = _class = /*#__PURE__*/function (_Component) {
    _inheritsLoose(WithOpenToggle, _Component);

    function WithOpenToggle() {
      var _this;

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      _this = _Component.call.apply(_Component, [this].concat(args)) || this;
      _this.state = {
        isOpen: Boolean(_this.props.isOpen)
      };

      _this.handleToggle = function (_, _temp2) {
        var _ref = _temp2 === void 0 ? {} : _temp2,
            isOpen = _ref.isOpen;

        _this.setState(function (prevState) {
          return {
            isOpen: isOpen !== undefined ? isOpen : !prevState.isOpen
          };
        });
      };

      return _this;
    }

    var _proto = WithOpenToggle.prototype;

    _proto.render = function render() {
      var handleToggle = this.handleToggle,
          props = this.props;
      var isOpen = this.state.isOpen;
      return /*#__PURE__*/_jsx(BaseComponent, _extends({}, props, {
        isOpen: isOpen,
        onToggle: handleToggle
      }));
    };

    return WithOpenToggle;
  }(Component), _class.displayName = "WithOpenToggle(" + displayName + ")", _temp;
});

==> hoc-1.36.0.tgz: package/lib/withOpenToggle.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { Component } from 'react';
import PropTypes from 'prop-types';
import { jsx as _jsx } from "react/jsx-runtime";
export default (function (BaseComponent) {
  var _class;

  var displayName = BaseComponent.displayName;
  return _class = /*#__PURE__*/function (_Component) {
    _inheritsLoose(WithOpenToggle, _Component);

    function WithOpenToggle() {
      var _this;

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      _this = _Component.call.apply(_Component, [this].concat(args)) || this;
      _this.state = {
        isOpen: Boolean(_this.props.isOpen)
      };

      _this.handleToggle = function (_, _temp) {
        var _ref = _temp === void 0 ? {} : _temp,
            isOpen = _ref.isOpen;

        _this.setState(function (prevState) {
          return {
            isOpen: isOpen !== undefined ? isOpen : !prevState.isOpen
          };
        });
      };

      return _this;
    }

    var _proto = WithOpenToggle.prototype;

    _proto.render = function render() {
      var handleToggle = this.handleToggle,
          props = this.props;
      var isOpen = this.state.isOpen;
      return /*#__PURE__*/_jsx(BaseComponent, _extends({}, props, {
        isOpen: isOpen,
        onToggle: handleToggle
      }));
    };

    return WithOpenToggle;
  }(Component), _class.displayName = "WithOpenToggle(" + displayName + ")", _class;
});
